Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(139)

Unified Diff: ui/arc/notification/arc_custom_notification_view.cc

Issue 2800383003: [Notifications] Drop tap gestures for ArcCustomNotificationView. (Closed)
Patch Set: Address comments. Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/arc/notification/arc_custom_notification_view.cc
diff --git a/ui/arc/notification/arc_custom_notification_view.cc b/ui/arc/notification/arc_custom_notification_view.cc
index 39c3c6e4337eb5797c2e18d6bbb02ad7862aee98..f15deff5d17e5fcf5e6f65ccb2e73b6bc3d24fcd 100644
--- a/ui/arc/notification/arc_custom_notification_view.cc
+++ b/ui/arc/notification/arc_custom_notification_view.cc
@@ -48,14 +48,17 @@ class ArcCustomNotificationView::EventForwarder : public ui::EventHandler {
ForwardScrollEvent(event->AsScrollEvent());
} else if (event->IsMouseWheelEvent()) {
ForwardMouseWheelEvent(event->AsMouseWheelEvent());
- } else if (!event->IsTouchEvent()) {
+ } else if (!event->IsTouchEvent() && event->type() != ui::ET_GESTURE_TAP) {
// TODO(yoshiki): Use a better tigger (eg. focusing EditText on
// notification) than clicking (crbug.com/697379).
if (event->type() == ui::ET_MOUSE_PRESSED)
owner_->ActivateToast();
// Forward the rest events to |owner_| except touches because View
// should no longer receive touch events. See View::OnTouchEvent.
owner_->OnEvent(event);
}
}
@@ -48,14 +48,17 @@ class ArcCustomNotificationView::EventForwarder : public ui::EventHandler {
if (event->type() == ui::ET_MOUSE_PRESSED)
owner_->ActivateToast();
- // Forward the rest events to |owner_| except touches because View
- // should no longer receive touch events. See View::OnTouchEvent.
+ // Forward the rest events to |owner_| except for:
+ // 1. Touches, because View should no longer receive touch events.
+ // See View::OnTouchEvent.
+ // 2. Tap gestures are handled on the Android side, so ignore them.
+ // See crbug.com/709911.
owner_->OnEvent(event);
}
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698